<?php

return [
    'number.decimals_separator' => ',',
    'number.thousands_separator' => '.',
    'None' => 'Ingen',
    'Edit' => 'Redigere',
    'Remove' => 'Fjerne',
    'Yes' => 'Ja',
    'No' => 'Nej',
    'cancel' => 'annullere',
    'or' => 'eller',
    'Yellow' => 'Gul',
    'Blue' => 'Blå',
    'Green' => 'Grøn',
    'Purple' => 'Lilla',
    'Red' => 'Rød',
    'Orange' => 'Orange',
    'Grey' => 'Grå',
    'Brown' => 'Brun',
    'Deep Orange' => 'Dyb orange',
    'Dark Grey' => 'Mørkegrå',
    'Pink' => 'Lyserød',
    'Teal' => 'Blågrøn',
    'Cyan' => 'Turkis',
    'Lime' => 'Citron',
    'Light Green' => 'Lysegrøn',
    'Amber' => 'Rav',
    'Save' => 'Gemme',
    'Login' => 'Logge ind',
    'Official website:' => 'Officielt netsted:',
    'Unassigned' => 'Ikke tildelt',
    'View this task' => 'Vis opgave',
    'Remove user' => 'Fjern bruger',
    'Do you really want to remove this user: "%s"?' => 'Fjern bruger: "%s"?',
    'All users' => 'Alle brugere',
    'Username' => 'Brugernavn',
    'Password' => 'Adgangskode',
    'Administrator' => 'Administrator',
    'Sign in' => 'Logge ind',
    'Users' => 'Brugere',
    'Forbidden' => 'Nægtet',
    'Access Forbidden' => 'Adgang nægtet',
    'Edit user' => 'Redigere bruger',
    'Logout' => 'Logge ud',
    'Bad username or password' => 'Forkert brugernavn eller adgangskode',
    'Edit project' => 'Redigere projekt',
    'Name' => 'Navn',
    'Projects' => 'Projekter',
    'No project' => 'Ingen projekt',
    'Project' => 'Projekt',
    'Status' => 'Status',
    'Tasks' => 'Opgaver',
    'Board' => 'Tavle',
    'Actions' => 'Handlinger',
    'Inactive' => 'Inaktiv',
    'Active' => 'Aktiv',
    'Unable to update this board.' => 'Kan ikke opdatere tavlen.',
    'Disable' => 'Deaktivere',
    'Enable' => 'Aktivere',
    'New project' => 'Nyt projekt',
    'Do you really want to remove this project: "%s"?' => 'Fjern projekt: "%s"?',
    'Remove project' => 'Fjern projekt',
    'Edit the board for "%s"' => 'Redigere tavlen for "%s"',
    'Add a new column' => 'Tilføj ny kolonne',
    'Title' => 'Titel',
    'Assigned to %s' => 'Tildelt %s',
    'Remove a column' => 'Fjern kolonne',
    'Unable to remove this column.' => 'Kan ikke fjerne kolonne.',
    'Do you really want to remove this column: "%s"?' => 'Fjern kolonne: "%s"?',
    'Settings' => 'Opsætning',
    'Application settings' => 'Program opsætning',
    'Language' => 'Sprog',
    'Webhook token:' => 'Net-hægte symbol:',
    'API token:' => 'API symbol:',
    'Database size:' => 'Database størrelse:',
    'Download the database' => 'Hente databasen',
    'Optimize the database' => 'Optimere databasen',
    '(VACUUM command)' => '(VACUUM kommando)',
    '(Gzip compressed Sqlite file)' => '(Gzip komprimeret SQLite fil)',
    'Close a task' => 'Lukke opgave',
    'Column' => 'Kolonne',
    'Color' => 'Farve',
    'Assignee' => 'Ansvarlig',
    'Create another task' => 'Opret anden opgave',
    'New task' => 'Ny opgave',
    'Open a task' => 'Åbne opgave',
    'Do you really want to open this task: "%s"?' => 'Åbne opgave: "%s"?',
    'Back to the board' => 'Tilbage til tavlen',
    'There is nobody assigned' => 'Ingen tildelt',
    'Column on the board:' => 'Kolonne på tavlen:',
    'Close this task' => 'Lukke opgave',
    'Open this task' => 'Åbne opgave',
    'There is no description.' => 'Ingen beskrivelse.',
    'Add a new task' => 'Tilføj ny opgave',
    'The username is required' => 'Brugernavn påkrævet',
    'The maximum length is %d characters' => 'Maksimale længde er %d tegn',
    'The minimum length is %d characters' => 'Mindste længde er %d tegn',
    'The password is required' => 'Adgangskode påkrævet',
    'This value must be an integer' => 'Værdien skal være et heltal',
    'The username must be unique' => 'Brugernavn skal være unikt',
    'The user id is required' => 'Bruger ID påkrævet',
    'Passwords don\'t match' => 'Adgangskoder stemmer ikke overens',
    'The confirmation is required' => 'Verifikation påkrævet',
    'The project is required' => 'Projekt påkrævet',
    'The id is required' => 'ID påkrævet',
    'The project id is required' => 'Projekt ID påkrævet',
    'The project name is required' => 'Projekt navn påkrævet',
    'The title is required' => 'Titel påkrævet',
    'Settings saved successfully.' => 'Opsætning gemt.',
    'Unable to save your settings.' => 'Kan ikke gemme opsætning.',
    'Database optimization done.' => 'Database optimering færdig.',
    'Your project has been created successfully.' => 'Projekt oprettet.',
    'Unable to create your project.' => 'Kan ikke oprette projekt.',
    'Project updated successfully.' => 'Projekt opdateret.',
    'Unable to update this project.' => 'Kan ikke opdatere projekt.',
    'Unable to remove this project.' => 'Kan ikke fjerne projekt.',
    'Project removed successfully.' => 'Projekt fjernet.',
    'Project activated successfully.' => 'Projekt aktiveret.',
    'Unable to activate this project.' => 'Kan ikke aktivere projekt.',
    'Project disabled successfully.' => 'Projekt deaktiveret.',
    'Unable to disable this project.' => 'Kan ikke deaktivere projekt.',
    'Unable to open this task.' => 'Kan ikke åbne opgave.',
    'Task opened successfully.' => 'Opgave åbnet.',
    'Unable to close this task.' => 'Kan ikke lukke opgave.',
    'Task closed successfully.' => 'Opgave lukket.',
    'Unable to update your task.' => 'Kan ikke opdatere opgave.',
    'Task updated successfully.' => 'Opgave opdateret.',
    'Unable to create your task.' => 'Kan ikke oprette opgave.',
    'Task created successfully.' => 'Opgave oprettet.',
    'User created successfully.' => 'Bruger oprettet.',
    'Unable to create your user.' => 'Kan ikke oprette bruger.',
    'User updated successfully.' => 'Bruger opdateret.',
    'User removed successfully.' => 'Bruger fjernet.',
    'Unable to remove this user.' => 'Kan ikke fjerne bruger.',
    'Board updated successfully.' => 'Tavle opdateret.',
    'Ready' => 'Klar',
    'Backlog' => 'Efterslæb',
    'Work in progress' => 'Igangværende',
    'Done' => 'Færdig',
    'Application version:' => 'Program version:',
    'Id' => 'ID',
    'Public link' => 'Offentlig henvisning',
    'Timezone' => 'Tidszone',
    'Sorry, I didn\'t find this information in my database!' => 'Kan ikke finde information i database!',
    'Page not found' => 'Side ikke fundet',
    'Complexity' => 'Kompleksitet',
    'Task limit' => 'Opgave begrænsning',
    'Task count' => 'Opgave tæller',
    'User' => 'Bruger',
    'Comments' => 'Kommentarer',
    'Comment is required' => 'Kommentar påkrævet',
    'Comment added successfully.' => 'Kommentar tilføjet.',
    'Unable to create your comment.' => 'Kan ikke oprette kommentar.',
    'Due Date' => 'Forfaldsdato',
    'Invalid date' => 'Ugyldig dato',
    'Automatic actions' => 'Automatiske handlinger',
    'Your automatic action has been created successfully.' => 'Automatiske handling oprettet.',
    'Unable to create your automatic action.' => 'Kan ikke oprette automatisk handling.',
    'Remove an action' => 'Fjern handling',
    'Unable to remove this action.' => 'Kan ikke fjerne handling.',
    'Action removed successfully.' => 'Handling fjernet.',
    'Automatic actions for the project "%s"' => 'Automatiske handlinger for projekt "%s"',
    'Add an action' => 'Tilføj handling',
    'Event name' => 'Begivenheds-navn',
    'Action' => 'Handling',
    'Event' => 'Begivenhed',
    'When the selected event occurs execute the corresponding action.' => 'Når valgt begivenhed opstår udføres tilsvarende handling.',
    'Next step' => 'Næste trin',
    'Define action parameters' => 'Bestemme handlings-parametre',
    'Do you really want to remove this action: "%s"?' => 'Fjern handling: "%s"?',
    'Remove an automatic action' => 'Fjern automatisk handling',
    'Assign the task to a specific user' => 'Tildel opgave til bestemt bruger',
    'Assign the task to the person who does the action' => 'Tildel opgave til bruger der udfører handling',
    'Duplicate the task to another project' => 'Kopiere opgave til andet projekt',
    'Move a task to another column' => 'Flyt opgave til anden kolonne',
    'Task modification' => 'Opgave ændring',
    'Task creation' => 'Opgave oprettelse',
    'Closing a task' => 'Lukke opgave',
    'Assign a color to a specific user' => 'Tildel farve til bestemt bruger',
    'Position' => 'Placering',
    'Duplicate to project' => 'Kopiere til projekt',
    'Duplicate' => 'Kopiere',
    'Link' => 'Henvis',
    'Comment updated successfully.' => 'Kommentar opdateret.',
    'Unable to update your comment.' => 'Kan ikke opdatere kommentar.',
    'Remove a comment' => 'Fjern kommentar',
    'Comment removed successfully.' => 'Kommentar fjernet.',
    'Unable to remove this comment.' => 'Kan ikke fjerne kommentar.',
    'Do you really want to remove this comment?' => 'Fjern kommentar?',
    'Current password for the user "%s"' => 'Nuværende adgangskode for bruger "%s"',
    'The current password is required' => 'Nuværende adgangskode påkrævet',
    'Wrong password' => 'Forkert adgangskode',
    'Unknown' => 'Ukendt',
    'Last logins' => 'Seneste log ind',
    'Login date' => 'Log ind dato',
    'Authentication method' => 'Godkendelses-metode',
    'IP address' => 'IP adresse',
    'User agent' => 'Bruger agent',
    'Persistent connections' => 'Vedvarende forbindelser',
    'No session.' => 'Ingen blivende forbindelse.',
    'Expiration date' => 'Udløbsdato',
    'Remember Me' => 'Husk mig',
    'Creation date' => 'Oprettelsesdato',
    'Everybody' => 'Alle',
    'Open' => 'Åben',
    'Closed' => 'Lukket',
    'Search' => 'Søg',
    'Nothing found.' => 'Intet fundet.',
    'Due date' => 'Forfaldsdato',
    'Description' => 'Beskrivelse',
    '%d comments' => '%d kommentarer',
    '%d comment' => '%d kommentar',
    'Email address invalid' => 'Ugyldig e-post adresse',
    'Your external account is not linked anymore to your profile.' => 'Ekstern konto ikke forbundet til profil.',
    'Unable to unlink your external account.' => 'Kan ikke fjerne henvisning til ekstern konto.',
    'External authentication failed' => 'Ekstern godkendelse mislykkedes',
    'Your external account is linked to your profile successfully.' => 'Ekstern konto forbundet til profil.',
    'Email' => 'E-post',
    'Task removed successfully.' => 'Opgave fjernet.',
    'Unable to remove this task.' => 'Kan ikke fjerne opgave.',
    'Remove a task' => 'Fjern opgave',
    'Do you really want to remove this task: "%s"?' => 'Fjern opgave: "%s"?',
    'Assign automatically a color based on a category' => 'Tildele automatisk farve baseret på kategori',
    'Assign automatically a category based on a color' => 'Tildele automatisk kategori baseret på farve',
    'Task creation or modification' => 'Opgave oprettelse eller ændring',
    'Category' => 'Kategori',
    'Category:' => 'Kategori:',
    'Categories' => 'Kategorier',
    'Your category has been created successfully.' => 'Kategori oprettet.',
    'This category has been updated successfully.' => 'Kategori opdateret.',
    'Unable to update this category.' => 'Kan ikke opdatere kategori.',
    'Remove a category' => 'Fjern kategori',
    'Category removed successfully.' => 'Kategori fjernet.',
    'Unable to remove this category.' => 'Kan ikke fjerne kategori.',
    'Category modification for the project "%s"' => 'Kategori ændring for projekt "%s"',
    'Category Name' => 'Kategori navn',
    'Add a new category' => 'Tilføj ny kategori',
    'Do you really want to remove this category: "%s"?' => 'Fjern kategori: "%s"?',
    'All categories' => 'Alle kategorier',
    'No category' => 'Ingen kategori',
    'The name is required' => 'Navn er påkrævet',
    'Remove a file' => 'Fjern fil',
    'Unable to remove this file.' => 'Kan ikke fjerne fil.',
    'File removed successfully.' => 'Fil fjernet.',
    'Attach a document' => 'Vedhæfte dokument',
    'Do you really want to remove this file: "%s"?' => 'Fjern fil: "%s"?',
    'Attachments' => 'Vedhæftninger',
    'Edit the task' => 'Redigere opgave',
    'Add a comment' => 'Tilføj kommentar',
    'Edit a comment' => 'Redigere kommentar',
    'Summary' => 'Oversigt',
    'Time tracking' => 'Tidsregistrering',
    'Estimate:' => 'Anslå:',
    'Spent:' => 'Brugt:',
    'Do you really want to remove this sub-task?' => 'Fjern delopgave?',
    'Remaining:' => 'Tilbageværende:',
    'hours' => 'timer',
    'estimated' => 'anslået',
    'Sub-Tasks' => 'Delopgaver',
    'Add a sub-task' => 'Tilføj delopgave',
    'Original estimate' => 'Original anslået',
    'Create another sub-task' => 'Opret anden delopgave',
    'Time spent' => 'Tidsforbrug',
    'Edit a sub-task' => 'Redigere delopgave',
    'Remove a sub-task' => 'Fjern delopgave',
    'The time must be a numeric value' => 'Tiden skal være numerisk værdi',
    'Todo' => 'At gøre',
    'In progress' => 'I gang',
    'Sub-task removed successfully.' => 'Delopgave fjernet.',
    'Unable to remove this sub-task.' => 'Kan ikke fjerne delopgave.',
    'Sub-task updated successfully.' => 'Delopgave opdateret.',
    'Unable to update your sub-task.' => 'Kan ikke opdatere delopgave.',
    'Unable to create your sub-task.' => 'Kan ikke oprette delopgave.',
    'Maximum size: ' => 'Maksimum størrelse: ',
    'Display another project' => 'Vis andet projekt',
    'Created by %s' => 'Oprettet af %s',
    'Tasks Export' => 'Opgave eksport',
    'Start Date' => 'Start dato',
    'Execute' => 'Udføre',
    'Task Id' => 'Opgave ID',
    'Creator' => 'Opretter',
    'Modification date' => 'Ændrings-dato',
    'Completion date' => 'Afslutningsdato',
    'Clone' => 'Klone',
    'Project cloned successfully.' => 'Projekt klonet..',
    'Unable to clone this project.' => 'Kan ikke klone projekt.',
    'Enable email notifications' => 'Aktivere e-post påmindelser',
    'Task position:' => 'Opgave placering:',
    'The task #%d has been opened.' => 'Opgave #%d åbnet.',
    'The task #%d has been closed.' => 'Opgave #%d lukket.',
    'Sub-task updated' => 'Delopgave opdateret',
    'Title:' => 'Titel:',
    'Status:' => 'Status:',
    'Assignee:' => 'Ansvarlig:',
    'Time tracking:' => 'Tidsregistrering:',
    'New sub-task' => 'Ny delopgave',
    'New attachment added "%s"' => 'Ny vedhæftning tilføjet "%s"',
    'New comment posted by %s' => 'Ny kommentar af %s',
    'New comment' => 'Ny kommentar',
    'Comment updated' => 'Kommentar opdateret',
    'New subtask' => 'Ny delopgave',
    'I only want to receive notifications for these projects:' => 'Modtage påmindelser for disse projekter:',
    'view the task on Kanboard' => 'vis opgave på Kanboard',
    'Public access' => 'Offentlig adgang',
    'Disable public access' => 'Deaktivere offentlig adgang',
    'Enable public access' => 'Aktivere offentlig adgang',
    'Public access disabled' => 'Offentlig adgang deaktiveret',
    'Move the task to another project' => 'Flyt opgave til andet projekt',
    'Move to project' => 'Flyt til projekt',
    'Do you really want to duplicate this task?' => 'Kopiere opgave?',
    'Duplicate a task' => 'Kopiere opgave',
    'External accounts' => 'Eksterne konti',
    'Account type' => 'Konto type',
    'Local' => 'Lokal',
    'Remote' => 'Fjern',
    'Enabled' => 'Aktiveret',
    'Disabled' => 'Deaktiveret',
    'Login:' => 'Log ind:',
    'Full Name:' => 'Fuldt navn:',
    'Email:' => 'E-post:',
    'Notifications:' => 'Påmindelser:',
    'Notifications' => 'Påmindelser',
    'Account type:' => 'Konto type:',
    'Edit profile' => 'Redigere profil',
    'Change password' => 'Ændre adgangskode',
    'Password modification' => 'Adgangskode ændring',
    'External authentications' => 'Ekstern godkendelse',
    'Never connected.' => 'Aldrig forbundet.',
    'No external authentication enabled.' => 'Ingen ekstern godkendelse aktiveret.',
    'Password modified successfully.' => 'Adgangskode ændret.',
    'Unable to change the password.' => 'Kan ikke ændre adgangskode.',
    'Change category' => 'Ændre kategori',
    '%s updated the task %s' => '%s opdatere opgave %s',
    '%s opened the task %s' => '%s åbne opgave %s',
    '%s moved the task %s to the position #%d in the column "%s"' => '%s flytte opgave %s til placering #%d i kolonne "%s"',
    '%s moved the task %s to the column "%s"' => '%s flyttet opgave %s til kolonne "%s"',
    '%s created the task %s' => '%s oprettet opgave %s',
    '%s closed the task %s' => '%s lukket opgave %s',
    '%s created a subtask for the task %s' => '%s oprettet delopgave for opgave %s',
    '%s updated a subtask for the task %s' => '%s opdateret delopgave for opgave %s',
    'Assigned to %s with an estimate of %s/%sh' => 'Tildelt %s med anslåning på %s/%st',
    'Not assigned, estimate of %sh' => 'Ikke tildelt, anslået til %st',
    '%s updated a comment on the task %s' => '%s opdateret kommentar på opgave %s',
    '%s commented the task %s' => '%s har kommenteret opgave %s',
    '%s\'s activity' => '%s\'s aktivitet',
    'RSS feed' => 'RSS nyheds-kilde',
    '%s updated a comment on the task #%d' => '%s opdaterede kommentar på opgave #%d',
    '%s commented on the task #%d' => '%s kommenterede på opgave #%d',
    '%s updated a subtask for the task #%d' => '%s opdaterede delopgave for opgave #%d',
    '%s created a subtask for the task #%d' => '%s oprettede delopgave for opgave #%d',
    '%s updated the task #%d' => '%s opdaterede opgave #%d',
    '%s created the task #%d' => '%s oprettede opgave #%d',
    '%s closed the task #%d' => '%s lukkede opgave #%d',
    '%s opened the task #%d' => '%s åbnede opgave #%d',
    'Activity' => 'Aktivitet',
    'Default values are "%s"' => 'Standard værdier er "%s"',
    'Default columns for new projects (Comma-separated)' => 'Standard kolonne for nye projekter (kommasepareret)',
    'Task assignee change' => 'Ændre opgave ansvarlig',
    '%s changed the assignee of the task #%d to %s' => '%s ændre ansvarlig for opgave #%d til %s',
    '%s changed the assignee of the task %s to %s' => '%s ændre ansvarlig for opgave %s til %s',
    'New password for the user "%s"' => 'Ny adgangskode til bruger "%s"',
    'Choose an event' => 'Vælge hændelse',
    'Create a task from an external provider' => 'Opret opgave fra ekstern udbyder',
    'Change the assignee based on an external username' => 'Ændre tildelt baseret på eksternt brugernavn',
    'Change the category based on an external label' => 'Ændre kategori baseret på ekstern etiket',
    'Reference' => 'Henvisning',
    'Label' => 'Etiket',
    'Database' => 'Database',
    'About' => 'Om',
    'Database driver:' => 'Database drivprogram:',
    'Board settings' => 'Tavle indstillinger',
    'Webhook settings' => 'Net-hægte indstillinger',
    'Reset token' => 'Nulstille symbol',
    'API endpoint:' => 'API slutpunkt:',
    'Refresh interval for personal board' => 'Opdaterings-frekvens for privat tavle',
    'Refresh interval for public board' => 'Opdaterings-frekvens for offentlig tavle',
    'Task highlight period' => 'Fremhæve opgave periode',
    'Period (in second) to consider a task was modified recently (0 to disable, 2 days by default)' => 'Periode (sekunder) for at betragte opgave nylig ændret (0 deaktiverer, standard 2 dage)',
    'Frequency in second (60 seconds by default)' => 'Frekvens i sekunder (standard 60 sekunder)',
    'Frequency in second (0 to disable this feature, 10 seconds by default)' => 'Frekvens i sekunder (0 deaktiverer funktion, standard 10 sekunder)',
    'Application URL' => 'Program URL',
    'Token regenerated.' => 'Symbol gendannet.',
    'Date format' => 'Dato format',
    'ISO format is always accepted, example: "%s" and "%s"' => 'ISO format accepteres altid, eksempelvis: "%s" og "%s"',
    'New personal project' => 'Nyt privat projekt',
    'This project is personal' => 'Privat projekt',
    'Add' => 'Tilføje',
    'Start date' => 'Start dato',
    'Time estimated' => 'Tid anslået',
    'There is nothing assigned to you.' => 'Intet tildelt.',
    'My tasks' => 'Tildelte opgaver',
    'Activity stream' => 'Aktivitet strøm',
    'Dashboard' => 'Instrumentbræt',
    'Confirmation' => 'Bekræftelse',
    'Webhooks' => 'Net-hægter',
    'API' => 'API',
    'Create a comment from an external provider' => 'Opret kommentar fra ekstern udbyder',
    'Project management' => 'Projekt styring',
    'Columns' => 'Kolonner',
    'Task' => 'Opgave',
    'Percentage' => 'Procent',
    'Number of tasks' => 'Antal opgaver',
    'Task distribution' => 'Opgave fordeling',
    'Analytics' => 'Analyse',
    'Subtask' => 'Delopgave',
    'User repartition' => 'Bruger fordeling',
    'Clone this project' => 'Kopiere projekt',
    'Column removed successfully.' => 'Kolonne fjernet.',
    'Not enough data to show the graph.' => 'Ikke nok data for at vise graf.',
    'Previous' => 'Forrige',
    'The id must be an integer' => 'ID\'et skal være heltal',
    'The project id must be an integer' => 'Projekt ID skal være heltal',
    'The status must be an integer' => 'Status skal være heltal',
    'The subtask id is required' => 'Delopgave ID påkrævet',
    'The subtask id must be an integer' => 'Delopgave ID skal være heltal',
    'The task id is required' => 'Opgave ID påkrævet',
    'The task id must be an integer' => 'Opgave ID skal være heltal',
    'The user id must be an integer' => 'Bruger ID skal være heltal',
    'This value is required' => 'Værdi påkrævet',
    'This value must be numeric' => 'Værdi skal være numerisk',
    'Unable to create this task.' => 'Kan ikke oprette opgave.',
    'Cumulative flow diagram' => 'Akkumuleret rutediagram',
    'Daily project summary' => 'Daglig projektoversigt',
    'Daily project summary export' => 'Daglig projektoversigt eksport',
    'Exports' => 'Eksportere',
    'This export contains the number of tasks per column grouped per day.' => 'Eksport indeholder antal opgaver pr. kolonne grupperet pr. dag.',
    'Active swimlanes' => 'Aktive spor',
    'Add a new swimlane' => 'Tilføj nyt spor',
    'Default swimlane' => 'Standard spor',
    'Do you really want to remove this swimlane: "%s"?' => 'Fjern spor: "%s"?',
    'Inactive swimlanes' => 'Inaktive spor',
    'Remove a swimlane' => 'Fjern spor',
    'Swimlane modification for the project "%s"' => 'Ændre spor for projekt "%s"',
    'Swimlane removed successfully.' => 'Spor fjernet.',
    'Swimlanes' => 'Spor',
    'Swimlane updated successfully.' => 'Spor opdateret.',
    'Unable to remove this swimlane.' => 'Kan ikke fjerne spor.',
    'Unable to update this swimlane.' => 'Kan ikke opdatere spor.',
    'Your swimlane has been created successfully.' => 'Spor oprettet.',
    'Example: "Bug, Feature Request, Improvement"' => 'Eksempel: "fejl, egenskab forespørgsel, forbedring"',
    'Default categories for new projects (Comma-separated)' => 'Standard kategorier for nye projekter (komma separeret)',
    'Integrations' => 'Integrationer',
    'Integration with third-party services' => 'Integration med 3. part tjenester',
    'Subtask Id' => 'Delopgave ID',
    'Subtasks' => 'Delopgaver',
    'Subtasks Export' => 'Delopgave eksport',
    'Task Title' => 'Opgave titel',
    'Untitled' => 'Intet navn',
    'Application default' => 'Program standard',
    'Language:' => 'Sprog:',
    'Timezone:' => 'Tidszone:',
    'All columns' => 'Alle kolonner',
    'Next' => 'Næste',
    '#%d' => '#%d',
    'All swimlanes' => 'Alle spor',
    'All colors' => 'Alle farver',
    'Moved to column %s' => 'Flyttet til kolonne %s',
    'User dashboard' => 'Bruger instrumentbræt',
    'Allow only one subtask in progress at the same time for a user' => 'Tillad én aktiv delopgave i gang på samme tid for bruger',
    'Edit column "%s"' => 'Redigere kolonne "%s"',
    'Select the new status of the subtask: "%s"' => 'Vælge ny status for delopgave: "%s"',
    'Subtask timesheet' => 'Delopgave tidsregistrering',
    'There is nothing to show.' => 'Ikke noget at vise.',
    'Time Tracking' => 'Tidsporing',
    'You already have one subtask in progress' => 'En delopgave er i gang',
    'Which parts of the project do you want to duplicate?' => 'Hvilke dele af projekt skal kopieres?',
    'Disallow login form' => 'Afvis log ind formular',
    'Start' => 'Start',
    'End' => 'Slut',
    'Task age in days' => 'Opgave tid i dage',
    'Days in this column' => 'Dage i kolonne',
    '%dd' => '%dd',
    'Add a new link' => 'Tilføj ny henvisning',
    'Do you really want to remove this link: "%s"?' => 'Fjern henvisning: "%s"?',
    'Do you really want to remove this link with task #%d?' => 'Fjern henvisning med opgave #%d?',
    'Field required' => 'Felt påkrævet',
    'Link added successfully.' => 'Henvisning tilføjet.',
    'Link updated successfully.' => 'Henvisning opdateret.',
    'Link removed successfully.' => 'Henvisning fjernet.',
    'Link labels' => 'Henvisning etiketter',
    'Link modification' => 'Henvisning ændring',
    'Opposite label' => 'Modsatte etiket',
    'Remove a link' => 'Fjern henvisning',
    'The labels must be different' => 'Etiketter skal være forskellige',
    'There is no link.' => 'Ingen henvisning.',
    'This label must be unique' => 'Etiket skal være unik',
    'Unable to create your link.' => 'Kan ikke oprette henvisning.',
    'Unable to update your link.' => 'Kan ikke opdatere henvisning.',
    'Unable to remove this link.' => 'Kan ikke fjerne henvisning.',
    'relates to' => 'vedrører',
    'blocks' => 'blokerer',
    'is blocked by' => 'er blokeret af',
    'duplicates' => 'dubletter',
    'is duplicated by' => 'er kopieret af',
    'is a child of' => 'er barn af',
    'is a parent of' => 'er forælder til',
    'targets milestone' => 'mål milepæl',
    'is a milestone of' => 'er milepæl af',
    'fixes' => 'rettelser',
    'is fixed by' => 'er rettet af',
    'This task' => 'Opgave',
    '<1h' => '<1t',
    '%dh' => '%dt',
    'Expand tasks' => 'Udfolde opgaver',
    'Collapse tasks' => 'Sammenfolde opgaver',
    'Expand/collapse tasks' => 'Udfolde/sammenfolde opgaver',
    'Close dialog box' => 'Lukke dialogboks',
    'Submit a form' => 'Indsende formular',
    'Board view' => 'Tavle visning',
    'Keyboard shortcuts' => 'Tastaturgenveje',
    'Open board switcher' => 'Åbne tavle skifter',
    'Application' => 'Program',
    'Compact view' => 'Kompakt visning',
    'Horizontal scrolling' => 'Vandret rulning',
    'Compact/wide view' => 'Kompakt/bred visning',
    'Currency' => 'Valuta',
    'Personal project' => 'Privat projekt',
    'AUD - Australian Dollar' => 'AUD - australsk dollar',
    'CAD - Canadian Dollar' => 'CAD - canadisk dollar',
    'CHF - Swiss Francs' => 'CHF - schweizisk franc',
    'Custom Stylesheet' => 'Brugertilpasset stilark',
    'EUR - Euro' => 'EUR - euro',
    'GBP - British Pound' => 'GBP - britisk pund',
    'INR - Indian Rupee' => 'INR - indisk rupee',
    'JPY - Japanese Yen' => 'JPY - japansk yen',
    'NZD - New Zealand Dollar' => 'NZD - new zealandsk dollar',
    'PEN - Peruvian Sol' => 'PEN – peruviansk sol',
    'RSD - Serbian dinar' => 'RSD - serbisk dinar',
    'CNY - Chinese Yuan' => 'CNY - kinesisk yuan',
    'USD - US Dollar' => 'USD - amerikansk dollar',
    'VES - Venezuelan Bolívar' => 'VES – venezuelansk bolívar',
    'Destination column' => 'Mål kolonne',
    'Move the task to another column when assigned to a user' => 'Flyt opgave til anden kolonne når den er tildelt bruger',
    'Move the task to another column when assignee is cleared' => 'Flyt opgave til anden kolonne når ansvarlig er ryddet',
    'Source column' => 'Kilde kolonne',
    'Transitions' => 'Overgange',
    'Executer' => 'Udfører',
    'Time spent in the column' => 'Tid brugt i kolonne',
    'Task transitions' => 'Opgave overgange',
    'Task transitions export' => 'Opgave overgange eksport',
    'This report contains all column moves for each task with the date, the user and the time spent for each transition.' => 'Rapport indeholder alle kolonne bevægelser for hver opgave med dato, bruger og tid der bruges til hver overgang.',
    'Currency rates' => 'Valutakurser',
    'Rate' => 'Kurs',
    'Change reference currency' => 'Ændre referencevaluta',
    'Reference currency' => 'Referencevaluta',
    'The currency rate has been added successfully.' => 'Valutakursen tilføjet.',
    'Unable to add this currency rate.' => 'Kan ikke tilføje valutakurs.',
    'Webhook URL' => 'Net-hægte URL',
    '%s removed the assignee of the task %s' => '%s fjernede ansvarlig for opgave %s',
    'Information' => 'Information',
    'Check two factor authentication code' => 'Kontrollere to-faktor godkendelses-kode',
    'The two factor authentication code is not valid.' => 'To-faktor godkendelses-kode ugyldig.',
    'The two factor authentication code is valid.' => 'To-faktor godkendelses-koden gyldig.',
    'Code' => 'Kode',
    'Two factor authentication' => 'To-faktor godkendelse',
    'This QR code contains the key URI: ' => 'QR kode indeholder nøgle URI: ',
    'Check my code' => 'Kontrollere kode',
    'Secret key: ' => 'Hemmelig nøgle: ',
    'Test your device' => 'Test enhed',
    'Assign a color when the task is moved to a specific column' => 'Tildele farve når opgave flyttes til bestemt kolonne',
    '%s via Kanboard' => '%s via Kanboard',
    'Burndown chart' => 'Burn-down diagram',
    'This chart show the task complexity over the time (Work Remaining).' => 'Diagram viser opgavekompleksitet over tid (resterende arbejde).',
    'Screenshot taken %s' => 'Skærmbillede taget %s',
    'Add a screenshot' => 'Tilføj skærmbillede',
    'Take a screenshot and press CTRL+V or ⌘+V to paste here.' => 'Tage skærmbillede og tryk på CTRL + V eller ⌘ + V for at indsætte her.',
    'Screenshot uploaded successfully.' => 'Skærmbillede overført.',
    'SEK - Swedish Krona' => 'SEK - svensk krone',
    'Identifier' => 'ID',
    'Disable two factor authentication' => 'Deaktivere to-faktor godkendelse',
    'Do you really want to disable the two factor authentication for this user: "%s"?' => 'Deaktivere to-faktor godkendelse for bruger: "%s"?',
    'Edit link' => 'Redigere henvisning',
    'Start to type task title...' => 'Start med at skrive opgave titel...',
    'A task cannot be linked to itself' => 'En opgave kan ikke henvise til sig selv',
    'The exact same link already exists' => 'Henvisning eksisterer allerede',
    'Recurrent task is scheduled to be generated' => 'Gentagende opgave planlagt at blive oprettet',
    'Score' => 'Bedømmelse',
    'The identifier must be unique' => 'ID skal være unik',
    'This linked task id doesn\'t exists' => 'Opgave ID henvisning eksisterer ikke',
    'This value must be alphanumeric' => 'Værdi skal være alfanumerisk',
    'Edit recurrence' => 'Redigere gentagelse',
    'Generate recurrent task' => 'Generere gentagende opgave',
    'Trigger to generate recurrent task' => 'Udløser for at generere gentagende opgave',
    'Factor to calculate new due date' => 'Faktor til beregning af ny forfaldsdato',
    'Timeframe to calculate new due date' => 'Tidsramme til beregning af ny forfaldsdato',
    'Base date to calculate new due date' => 'Grund dato til beregning af ny forfaldsdato',
    'Action date' => 'Handlings-dato',
    'Base date to calculate new due date: ' => 'Grund dato til beregning af ny forfaldsdato: ',
    'This task has created this child task: ' => 'Opgave har oprettet barne opgave: ',
    'Day(s)' => 'Dag(e)',
    'Existing due date' => 'Eksisterende forfaldsdato',
    'Factor to calculate new due date: ' => 'Faktor til beregning af ny forfaldsdato: ',
    'Month(s)' => 'Måned(er)',
    'This task has been created by: ' => 'Opgave oprettet af: ',
    'Recurrent task has been generated:' => 'Gentagende opgave oprettet:',
    'Timeframe to calculate new due date: ' => 'Tidsramme til beregning af ny forfaldsdato: ',
    'Trigger to generate recurrent task: ' => 'Udløser for at generere gentagende opgave: ',
    'When task is closed' => 'Når opgave er lukket',
    'When task is moved from first column' => 'Når opgave flyttes fra første kolonne',
    'When task is moved to last column' => 'Når opgave flyttes til sidste kolonne',
    'Year(s)' => 'År',
    'Project settings' => 'Projekt indstillinger',
    'Automatically update the start date' => 'Opdatere automatisk startdato',
    'iCal feed' => 'iCal nyheds-kilde',
    'Preferences' => 'Indstillinger',
    'Security' => 'Sikkerhed',
    'Two factor authentication disabled' => 'To-faktor godkendelse deaktiveret',
    'Two factor authentication enabled' => 'To-faktor godkendelse aktiveret',
    'Unable to update this user.' => 'Kan ikke opdatere bruger.',
    'There is no user management for personal projects.' => 'Ingen bruger styring til private projekter.',
    'User that will receive the email' => 'Bruger der modtager e-post',
    'Email subject' => 'E-post emne',
    'Date' => 'Dato',
    'Add a comment log when moving the task between columns' => 'Tilføj kommentar log når opgave flyttes mellem kolonner',
    'Move the task to another column when the category is changed' => 'Flyt opgave til anden kolonne når kategori ændres',
    'Send a task by email to someone' => 'Sende opgave som e-post til nogen',
    'Reopen a task' => 'Genåbne opgave',
    'Notification' => 'Påmindelse',
    '%s moved the task #%d to the first swimlane' => '%s flyttet opgave #%d til første spor',
    'Swimlane' => 'Spor',
    '%s moved the task %s to the first swimlane' => '%s flyttet opgave %s til første spor',
    '%s moved the task %s to the swimlane "%s"' => '%s flyttet opgave %s til spor "%s"',
    'This report contains all subtasks information for the given date range.' => 'Rapport indeholder alle delopgave oplysninger for dato periode.',
    'This report contains all tasks information for the given date range.' => 'Rapport indeholder alle opgave oplysninger for dato periode.',
    'Project activities for %s' => 'Projekt aktiviteter for %s',
    'view the board on Kanboard' => 'vis tavle på Kanboard',
    'The task has been moved to the first swimlane' => 'Opgave flyttet til første spor',
    'The task has been moved to another swimlane:' => 'Opgave flyttet til andet spor:',
    'New title: %s' => 'Ny titel: %s',
    'The task is not assigned anymore' => 'Opgave ikke tildelt længere',
    'New assignee: %s' => 'Ny ansvarlig: %s',
    'There is no category now' => 'Ingen kategori nu',
    'New category: %s' => 'Ny kategori: %s',
    'New color: %s' => 'Ny farve: %s',
    'New complexity: %d' => 'Ny kompleksitet: %d',
    'The due date has been removed' => 'Forfaldsdato fjernet',
    'There is no description anymore' => 'Ingen beskrivelse mere',
    'Recurrence settings has been modified' => 'Gentagelse indstillinger ændret',
    'Time spent changed: %sh' => 'Tid forbrugt ændret: %st',
    'Time estimated changed: %sh' => 'Tid anslået ændret: %st',
    'The field "%s" has been updated' => 'Felt "%s" opdateret',
    'The description has been modified:' => 'Beskrivelse ændret:',
    'Do you really want to close the task "%s" as well as all subtasks?' => 'Lukke opgave "%s" og alle delopgaver?',
    'I want to receive notifications for:' => 'Bruger modtager underretninger for:',
    'All tasks' => 'Alle opgaver',
    'Only for tasks assigned to me' => 'Kun tildelte opgaver',
    'Only for tasks created by me' => 'Kun opgaver oprettet af bruger',
    'Only for tasks created by me and tasks assigned to me' => 'Kun opgaver oprettet og tildelt bruger',
    '%%Y-%%m-%%d' => '%%Y-%%m-%%d',
    'Total for all columns' => 'Total for alle kolonner',
    'You need at least 2 days of data to show the chart.' => 'Der skal mindst 2 dages data for at vise diagram.',
    '<15m' => '<15m',
    '<30m' => '<30m',
    'Stop timer' => 'Stop stopur',
    'Start timer' => 'Start stopur',
    'My activity stream' => 'Aktivitet strøm',
    'Search tasks' => 'Søg opgaver',
    'Reset filters' => 'Nulstille filtre',
    'My tasks due tomorrow' => 'Tildelte opgaver i morgen',
    'Tasks due today' => 'Opgaver i dag',
    'Tasks due tomorrow' => 'Opgaver i morgen',
    'Tasks due yesterday' => 'Opgaver i går',
    'Closed tasks' => 'Lukket opgaver',
    'Open tasks' => 'Åbne opgaver',
    'Not assigned' => 'Ikke tildelt',
    'View advanced search syntax' => 'Vis avanceret søge syntaks',
    'Overview' => 'Oversigt',
    'Board/Calendar/List view' => 'Tavle / kalender / liste visning',
    'Switch to the board view' => 'Skift til tavle visning',
    'Switch to the list view' => 'Skift til liste visning',
    'Go to the search/filter box' => 'Gå til søg- / filter-boks',
    'There is no activity yet.' => 'Endnu ingen aktivitet.',
    'No tasks found.' => 'Ingen opgave fundet.',
    'Keyboard shortcut: "%s"' => 'Tastaturgenvej: ”%s”',
    'List' => 'Liste',
    'Filter' => 'Filter',
    'Advanced search' => 'Avanceret søgning',
    'Example of query: ' => 'Forespørgsel eksempel: ',
    'Search by project: ' => 'Søg efter projekt: ',
    'Search by column: ' => 'Søg efter kolonne: ',
    'Search by assignee: ' => 'Søg ved ansvarlig: ',
    'Search by color: ' => 'Søg efter farve: ',
    'Search by category: ' => 'Søg efter kategori: ',
    'Search by description: ' => 'Søg efter beskrivelse: ',
    'Search by due date: ' => 'Søg efter forfaldsdato: ',
    'Average time spent in each column' => 'Gennemsnitlig tid forbrugt i hver kolonne',
    'Average time spent' => 'Gennemsnitlig tid forbrugt',
    'This chart shows the average time spent in each column for the last %d tasks.' => 'Diagram viser gennemsnitlig tid i hver kolonne for de seneste %d opgaver.',
    'Average Lead and Cycle time' => 'Gennemsnitlig hoved- og gennemløbstid',
    'Average lead time: ' => 'Gennemsnitlig hoved tid: ',
    'Average cycle time: ' => 'Gennemsnitlig gennemløbstid: ',
    'Cycle Time' => 'Gennemløbstid',
    'Lead Time' => 'Hoved tid',
    'This chart shows the average lead and cycle time for the last %d tasks over the time.' => 'Diagram viser gennemsnitlig hoved- og gennemløbstid for de seneste %d opgaver over tid.',
    'Average time into each column' => 'Gennemsnitlig tid i hver kolonne',
    'Lead and cycle time' => 'Hoved- og gennemløbstid',
    'Lead time: ' => 'Hoved tid: ',
    'Cycle time: ' => 'Gennemløbstid: ',
    'Time spent in each column' => 'Tid forbrugt i hver kolonne',
    'The lead time is the duration between the task creation and the completion.' => 'Hoved tid er varighed mellem opgaveoprettelse og færdiggørelse.',
    'The cycle time is the duration between the start date and the completion.' => 'Gennemløbstid er varighed mellem startdato og færdiggørelse.',
    'If the task is not closed the current time is used instead of the completion date.' => 'Hvis opgave ikke er lukket bruges nuværende tid i stedet for færdiggørelses-dato.',
    'Set the start date automatically' => 'Angive automatisk startdato',
    'Edit Authentication' => 'Redigere godkendelse',
    'Remote user' => 'Fjern bruger',
    'Remote users do not store their password in Kanboard database, examples: LDAP, Google and Github accounts.' => 'Fjern brugere gemmer ikke adgangskode i Kanboard databasen; eksempler: LDAP, Google og Github konti.',
    'If you check the box "Disallow login form", credentials entered in the login form will be ignored.' => 'Ved at markere afkrydsnings-felt "Tillad ikke log ind formular" ignoreres legitimations-oplysninger, der er indtastet i log ind formular.',
    'Default task color' => 'Standard opgave farve',
    'This feature does not work with all browsers.' => 'Funktion virker ikke med alle netlæsere.',
    'There is no destination project available.' => 'Ingen mål projekt tilgængelig.',
    'Trigger automatically subtask time tracking' => 'Udløser automatisk delopgave tidsporing',
    'Include closed tasks in the cumulative flow diagram' => 'Inkludere lukkede opgaver i kumulativ rutediagram',
    'Current swimlane: %s' => 'Nuværende spor: %s',
    'Current column: %s' => 'Nuværende kolonne: %s',
    'Current category: %s' => 'Nuværende kategori: %s',
    'no category' => 'ingen kategori',
    'Current assignee: %s' => 'Nuværende ansvarlig: %s',
    'not assigned' => 'ikke tildelt',
    'Author:' => 'Forfatter:',
    'contributors' => 'bidragsydere',
    'License:' => 'Licens:',
    'License' => 'Licens',
    'Enter the text below' => 'Indtast tekst nedenfor',
    'Start date:' => 'Start dato:',
    'Due date:' => 'Forfaldsdato:',
    'People who are project managers' => 'Personer der er projektledere',
    'People who are project members' => 'Personer der er projektmedlemmer',
    'NOK - Norwegian Krone' => 'NOK - norsk krone',
    'Show this column' => 'Vis kolonne',
    'Hide this column' => 'Skjul kolonne',
    'End date' => 'Slut dato',
    'Users overview' => 'Bruger oversigt',
    'Members' => 'Medlemmer',
    'Shared project' => 'Delt projekt',
    'Project managers' => 'Projektledere',
    'Projects list' => 'Projekt liste',
    'End date:' => 'Slut dato:',
    'Change task color when using a specific task link' => 'Ændre opgave farve når der bruges bestemt opgave henvisning',
    'Task link creation or modification' => 'Opgave henvisning oprettelse eller ændring',
    'Milestone' => 'Milepæl',
    'Reset the search/filter box' => 'Nulstil søg- / filter-boks',
    'Documentation' => 'Dokumentation',
    'Author' => 'Forfatter',
    'Version' => 'Version',
    'Plugins' => 'Udvidelses-moduler',
    'There is no plugin loaded.' => 'Ingen udvidelses-modul indlæst.',
    'My notifications' => 'Tildelte påmindelser',
    'Custom filters' => 'Brugertilpasset filtre',
    'Your custom filter has been created successfully.' => 'Brugertilpasset filter oprettet.',
    'Unable to create your custom filter.' => 'Kan ikke oprette brugertilpasset filter.',
    'Custom filter removed successfully.' => 'Brugertilpasset filter fjernet.',
    'Unable to remove this custom filter.' => 'Kan ikke fjerne brugertilpasset filter.',
    'Edit custom filter' => 'Redigere brugertilpasset filter',
    'Your custom filter has been updated successfully.' => 'Brugertilpasset filter opdateret.',
    'Unable to update custom filter.' => 'Kan ikke opdatere brugertilpasset filter.',
    'Web' => 'Net',
    'New attachment on task #%d: %s' => 'Ny vedhæftet fil til opgave #%d: %s',
    'New comment on task #%d' => 'Ny kommentar til opgave #%d',
    'Comment updated on task #%d' => 'Kommentar opdateret til opgave #%d',
    'New subtask on task #%d' => 'Ny delopgave til opgave #%d',
    'Subtask updated on task #%d' => 'Delopgave opdateret til opgave #%d',
    'New task #%d: %s' => 'Ny opgave #%d: %s',
    'Task updated #%d' => 'Opgave opdateret #%d',
    'Task #%d closed' => 'Opgave #%d lukket',
    'Task #%d opened' => 'Opgave #%d åbnet',
    'Column changed for task #%d' => 'Kolonne ændret for opgave #%d',
    'New position for task #%d' => 'Ny placering for opgave #%d',
    'Swimlane changed for task #%d' => 'Spor ændret for opgave #%d',
    'Assignee changed on task #%d' => 'Tildelte ændret til opgave #%d',
    '%d overdue tasks' => '%d forsinkede opgaver',
    'No notification.' => 'Ingen påmindelse.',
    'Mark all as read' => 'Markere alle som læst',
    'Mark as read' => 'Markere som læst',
    'Total number of tasks in this column across all swimlanes' => 'Samlet antal opgaver i kolonne på tværs af alle spor',
    'Collapse swimlane' => 'Sammenfolde spor',
    'Expand swimlane' => 'Udfolde spor',
    'Add a new filter' => 'Tilføj nyt filter',
    'Share with all project members' => 'Del med alle projektmedlemmer',
    'Shared' => 'Delt',
    'Owner' => 'Ejer',
    'Unread notifications' => 'Ulæste påmindelser',
    'Notification methods:' => 'Påmindelse metoder:',
    'Unable to read your file' => 'Kan ikke læse fil',
    '%d task(s) have been imported successfully.' => '%d opgave(er) blev importeret.',
    'Nothing has been imported!' => 'Intet blev importeret!',
    'Import users from CSV file' => 'Importere brugere fra CSV fil',
    '%d user(s) have been imported successfully.' => '%d bruger(e) blev importeret.',
    'Comma' => 'Komma',
    'Semi-colon' => 'Semikolon',
    'Tab' => 'Fane',
    'Vertical bar' => 'Lodret bjælke',
    'Double Quote' => 'Dobbelt citat',
    'Single Quote' => 'Enkelt citat',
    '%s attached a file to the task #%d' => '%s vedhæftet fil til opgave #%d',
    'There is no column or swimlane activated in your project!' => 'Ingen kolonne eller spor aktiveret i projekt!',
    'Append filter (instead of replacement)' => 'Tilføj filter (i stedet for udskiftning)',
    'Append/Replace' => 'Tilføj / erstat',
    'Append' => 'Tilføj',
    'Replace' => 'Erstat',
    'Import' => 'Importer',
    'Change sorting' => 'Ændre sortering',
    'Tasks Importation' => 'Opgaver Import',
    'Delimiter' => 'Afgrænse',
    'Enclosure' => 'Indeluk',
    'CSV File' => 'CSV fil',
    'Instructions' => 'Instruktioner',
    'Your file must use the predefined CSV format' => 'Filen skal bruge forudbestemt CSV format',
    'Your file must be encoded in UTF-8' => 'Fil skal være indkodet i UTF-8',
    'The first row must be the header' => 'Første række skal være overskrift',
    'Duplicates are not verified for you' => 'Dubletter er ikke efterprøvet',
    'The due date must use the ISO format: YYYY-MM-DD' => 'Forfaldsdato skal bruge ISO-format: ÅÅÅÅ-MM-DD',
    'Download CSV template' => 'Hente CSV skabelon',
    'No external integration registered.' => 'Ingen ekstern integration registreret.',
    'Duplicates are not imported' => 'Dubletter importeres ikke',
    'Usernames must be lowercase and unique' => 'Brugernavn skal være små bogstaver og unik',
    'Passwords will be encrypted if present' => 'Adgangskoder krypteres hvis tilstede',
    '%s attached a new file to the task %s' => '%s knytte ny fil til opgave %s',
    'Link type' => 'Henvisning type',
    'Assign automatically a category based on a link' => 'Tildele automatisk kategori baseret på henvisning',
    'BAM - Konvertible Mark' => 'BAM - mærke kan konverteres',
    'Assignee Username' => 'Ansvarligs brugernavn',
    'Assignee Name' => 'Ansvarligs navn',
    'Groups' => 'Grupper',
    'Members of %s' => 'Medlemmer af %s',
    'New group' => 'Ny gruppe',
    'Group created successfully.' => 'Gruppe oprettet.',
    'Unable to create your group.' => 'Kan ikke oprette gruppe.',
    'Edit group' => 'Redigere gruppe',
    'Group updated successfully.' => 'Gruppe opdateret.',
    'Unable to update your group.' => 'Kan ikke opdatere gruppe.',
    'Add group member to "%s"' => 'Tilføj gruppemedlem til "%s"',
    'Group member added successfully.' => 'Gruppemedlem tilføjet.',
    'Unable to add group member.' => 'Kan ikke tilføje gruppemedlem.',
    'Remove user from group "%s"' => 'Fjern bruger fra gruppe "%s"',
    'User removed successfully from this group.' => 'Fjernet bruger fra gruppe.',
    'Unable to remove this user from the group.' => 'Kan ikke fjerne bruger fra gruppe.',
    'Remove group' => 'Fjern gruppe',
    'Group removed successfully.' => 'Gruppe fjernet.',
    'Unable to remove this group.' => 'Kan ikke fjerne gruppe.',
    'Project Permissions' => 'Projekt tilladelser',
    'Manager' => 'Leder',
    'Project Manager' => 'Projektleder',
    'Project Member' => 'Projektmedlem',
    'Project Viewer' => 'Projekt betragter',
    'Your account is locked for %d minutes' => 'Konto låst i %d minutter',
    'Invalid captcha' => 'Ugyldig CAPTCHA',
    'The name must be unique' => 'Navn skal være unik',
    'View all groups' => 'Vis alle grupper',
    'There is no user available.' => 'Ingen bruger tilgængelig.',
    'Do you really want to remove the user "%s" from the group "%s"?' => 'Fjern bruger "%s" fra gruppe "%s"?',
    'There is no group.' => 'Ingen gruppe.',
    'Add group member' => 'Tilføj gruppe medlem',
    'Do you really want to remove this group: "%s"?' => 'Fjern gruppe: "%s"?',
    'There is no user in this group.' => 'Ingen bruger i gruppe.',
    'Permissions' => 'Tilladelser',
    'Allowed Users' => 'Tillad brugere',
    'No specific user has been allowed.' => 'Ingen bruger specifik tilladt.',
    'Role' => 'Rolle',
    'Enter user name...' => 'Indtast brugernavn...',
    'Allowed Groups' => 'Tillad grupper',
    'No group has been allowed.' => 'Ingen gruppe specifik tilladt.',
    'Group' => 'Gruppe',
    'Group Name' => 'Gruppenavn',
    'Enter group name...' => 'Indtast gruppenavn...',
    'Role:' => 'Rolle:',
    'Project members' => 'Projektmedlemmer',
    '%s mentioned you in the task #%d' => '%s nævnte bruger i opgave #%d',
    '%s mentioned you in a comment on the task #%d' => '%s nævnte bruger i kommentar til opgave #%d',
    'You were mentioned in the task #%d' => 'Bruger nævnt i opgave #%d',
    'You were mentioned in a comment on the task #%d' => 'Bruger nævnt i kommentar til opgave #%d',
    'Estimated hours: ' => 'Anslåede timer: ',
    'Actual hours: ' => 'Faktiske timer: ',
    'Hours Spent' => 'Forbrugte timer:',
    'Hours Estimated' => 'Anslåede timer',
    'Estimated Time' => 'Anslået tid',
    'Actual Time' => 'Faktiske tid',
    'Estimated vs actual time' => 'Anslået mod faktisk tid',
    'RUB - Russian Ruble' => 'RUB - russisk rubel',
    'Assign the task to the person who does the action when the column is changed' => 'Tildele opgave til person som begår handlingen når kolonnen ændres',
    'Close a task in a specific column' => 'Lukke opgave i bestemt kolonne',
    'Time-based One-time Password Algorithm' => 'Tidsbaseret engangs-adgangskode algoritme',
    'Two-Factor Provider: ' => 'To-faktor udbyder: ',
    'Disable two-factor authentication' => 'Deaktivere to-faktor godkendelse',
    'Enable two-factor authentication' => 'Aktivere to-faktor godkendelse',
    'There is no integration registered at the moment.' => 'Ingen integration registreret i øjeblikket.',
    'Password Reset for Kanboard' => 'Nulstille adgangskode for Kanboard',
    'Forgot password?' => 'Glemt adgangskode?',
    'Enable "Forget Password"' => 'Aktivere "Glemme adgangskode"',
    'Password Reset' => 'Nulstille adgangskode',
    'New password' => 'Ny adgangskode',
    'Change Password' => 'Ændre adgangskode',
    'To reset your password click on this link:' => 'For at nulstille adgangskode klik på henvisning:',
    'Last Password Reset' => 'Adgangskode senest nulstillet',
    'The password has never been reinitialized.' => 'Adgangskode aldrig nulstillet.',
    'Creation' => 'Oprettelse',
    'Expiration' => 'Udløb',
    'Password reset history' => 'Adgangskode nulstille historik',
    'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => 'Alle opgaver i kolonne "%s" og spor "%s" blev lukket.',
    'Do you really want to close all tasks of this column?' => 'Lukke alle opgaver i kolonnen?',
    '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '%d opgave(r) i kolonne "%s" og spor "%s" lukkes.',
    'Close all tasks in this column and this swimlane' => 'Lukke alle opgaver i kolonne',
    'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => 'Ingen udvidelses-modul har registreret projekt påmindelses-metode Brugeren kan stadig konfigurere individuelle påmindelser i brugerprofil.',
    'My dashboard' => 'Instrumentbræt',
    'My profile' => 'Profil',
    'Project owner: ' => 'Projekt ejer: ',
    'The project identifier is optional and must be alphanumeric, example: MYPROJECT.' => 'Projekt ID valgfri og skal være alfanumerisk; eksempel: MitProjekt.',
    'Project owner' => 'Projekt ejer',
    'Personal projects do not have users and groups management.' => 'Private projekter har ikke bruger og gruppe styring.',
    'There is no project member.' => 'Ingen projekt medlem.',
    'Priority' => 'Prioritet',
    'Task priority' => 'Opgave prioritet',
    'General' => 'Generelt',
    'Dates' => 'Datoer',
    'Default priority' => 'Standard prioritet',
    'Lowest priority' => 'Laveste prioritet',
    'Highest priority' => 'Højeste prioritet',
    'Close a task when there is no activity' => 'Lukke opgave når der ikke er aktivitet',
    'Duration in days' => 'Varighed i dage',
    'Send email when there is no activity on a task' => 'Sende e-post når der ikke er aktivitet på opgave',
    'Unable to fetch link information.' => 'Kan ikke hente henvisning informationer.',
    'Daily background job for tasks' => 'Daglige baggrundsjob til opgaver',
    'Auto' => 'Auto',
    'Related' => 'Relateret',
    'Attachment' => 'Vedhæftning',
    'Title not found' => 'Titel ikke fundet',
    'Web Link' => 'Net henvisning',
    'External links' => 'Eksterne henvisninger',
    'Add external link' => 'Tilføj ekstern henvisning',
    'Type' => 'Type',
    'Dependency' => 'Afhængighed',
    'Add internal link' => 'Tilføj intern henvisning',
    'Add a new external link' => 'Tilføj ny ekstern henvisning',
    'Edit external link' => 'Rette ekstern henvisning',
    'External link' => 'Ekstern henvisning',
    'Copy and paste your link here...' => 'Kopiere og indsætte henvisning her...',
    'URL' => 'URL',
    'Internal links' => 'Intern henvisning',
    'Assign to me' => 'Tildele bruger',
    'Me' => 'Bruger',
    'Do not duplicate anything' => 'Kopiere ikke noget',
    'Projects management' => 'Projekt styring',
    'Users management' => 'Bruger styring',
    'Groups management' => 'Gruppe styring',
    'Create from another project' => 'Opret fra andet projekt',
    'open' => 'åben',
    'closed' => 'lukket',
    'Priority:' => 'Prioritet:',
    'Reference:' => 'Reference:',
    'Complexity:' => 'Kompleksitet:',
    'Swimlane:' => 'Spor:',
    'Column:' => 'Kolonne:',
    'Position:' => 'Placering:',
    'Creator:' => 'Opretter:',
    'Time estimated:' => 'Tid anslået:',
    '%s hours' => '%s timer',
    'Time spent:' => 'Tid brugt:',
    'Created:' => 'Oprettet:',
    'Modified:' => 'Ændret:',
    'Completed:' => 'Afsluttet:',
    'Started:' => 'Startet:',
    'Moved:' => 'Flyttet:',
    'Task #%d' => 'Opgave #%d',
    'Time format' => 'Tidsformat',
    'Start date: ' => 'Start dato: ',
    'End date: ' => 'Slut dato: ',
    'New due date: ' => 'Ny forfalds-dato: ',
    'Start date changed: ' => 'Start dato ændret: ',
    'Disable personal projects' => 'Deaktivere private projekter',
    'Do you really want to remove this custom filter: "%s"?' => 'Fjern brugertilpasset filter: "%s"?',
    'Remove a custom filter' => 'Fjern brugertilpasset filter',
    'User activated successfully.' => 'Bruger aktiveret.',
    'Unable to enable this user.' => 'Kan ikke aktivere bruger.',
    'User disabled successfully.' => 'Bruger deaktiveret.',
    'Unable to disable this user.' => 'Kan ikke deaktivere bruger.',
    'All files have been uploaded successfully.' => 'Alle filer overført.',
    'The maximum allowed file size is %sB.' => 'Den maksimale filstørrelse er %sB.',
    'Drag and drop your files here' => 'Træk og slip filer her',
    'choose files' => 'vælg filer',
    'View profile' => 'Vis profil',
    'Two Factor' => 'To-faktor',
    'Disable user' => 'Deaktivere bruger',
    'Do you really want to disable this user: "%s"?' => 'Deaktivere bruger: "%s"?',
    'Enable user' => 'Aktivere bruger',
    'Do you really want to enable this user: "%s"?' => 'Aktivere bruger: "%s"?',
    'Download' => 'Hente',
    'Uploaded: %s' => 'Overført: %s',
    'Size: %s' => 'Størrelse: %s',
    'Uploaded by %s' => 'Overført af %s',
    'Filename' => 'Filnavn',
    'Size' => 'Størrelse',
    'Column created successfully.' => 'Kolonne oprettet.',
    'Another column with the same name exists in the project' => 'Der findes anden kolonne med samme navn i projekt',
    'Default filters' => 'Standard filtre',
    'Your board doesn\'t have any columns!' => 'Tavle har ingen kolonner!',
    'Change column position' => 'Ændre kolonne placering',
    'Switch to the project overview' => 'Skifte til projekt oversigt',
    'User filters' => 'Bruger filtre',
    'Category filters' => 'Kategori filtre',
    'Upload a file' => 'Overføre fil',
    'View file' => 'Vis fil',
    'Last activity' => 'Seneste aktivitet',
    'Change subtask position' => 'Ændre delopgave placering',
    'This value must be greater than %d' => 'Værdi skal være større end %d',
    'Another swimlane with the same name exists in the project' => 'Der findes andet spor med samme navn i projekt',
    'Example: https://example.kanboard.org/ (used to generate absolute URLs)' => 'Eksempel: https://example.kanboard.org/ (bruges til at generere absolutte URLer)',
    'Actions duplicated successfully.' => 'Handlinger kopieret.',
    'Unable to duplicate actions.' => 'Kan ikke kopiere handlinger.',
    'Add a new action' => 'Tilføj ny handling',
    'Import from another project' => 'Importere fra andet projekt',
    'There is no action at the moment.' => 'Ingen handling i øjeblikket.',
    'Import actions from another project' => 'Importere handlinger fra andet projekt',
    'There is no available project.' => 'Ingen projekt tilgængelig.',
    'Local File' => 'Lokal fil',
    'Configuration' => 'Indstillinger',
    'PHP version:' => 'PHP version:',
    'PHP SAPI:' => 'PHP SAPI:',
    'OS version:' => 'OS version:',
    'Database version:' => 'Database version:',
    'Browser:' => 'Netlæser:',
    'Task view' => 'Opgave oversigt',
    'Edit task' => 'Redigere opgave',
    'Edit description' => 'Redigere beskrivelse',
    'New internal link' => 'Ny intern henvisning',
    'Display list of keyboard shortcuts' => 'Vis liste over tastaturgenveje',
    'Avatar' => 'Ikon',
    'Upload my avatar image' => 'Overføre ikon billede',
    'Remove my image' => 'Fjern billede',
    'The OAuth2 state parameter is invalid' => 'Ugyldig OAuth2 tilstands-parameter',
    'User not found.' => 'Bruger ikke fundet.',
    'Search in activity stream' => 'Søg i aktivitet strøm',
    'My activities' => 'Tildelte aktiviteter',
    'Activity until yesterday' => 'Aktivitet indtil i går',
    'Activity until today' => 'Aktivitet indtil i dag',
    'Search by creator: ' => 'Søg efter opretter: ',
    'Search by creation date: ' => 'Søg efter oprettelsesdato: ',
    'Search by task status: ' => 'Søg efter opgave status: ',
    'Search by task title: ' => 'Søg efter opgavetitel: ',
    'Activity stream search' => 'Aktivitet strøm søgning',
    'Projects where "%s" is manager' => 'Projekter hvor "%s" er leder',
    'Projects where "%s" is member' => 'Projekter, hvor "%s" er medlem',
    'Open tasks assigned to "%s"' => 'Åbne opgaver tildelt "%s"',
    'Closed tasks assigned to "%s"' => 'Lukkede opgaver tildelt "%s"',
    'Assign automatically a color based on a priority' => 'Tildele automatisk farve baseret på prioritet',
    'Overdue tasks for the project(s) "%s"' => 'Forfaldne opgaver for projekt(er) "%s"',
    'Upload files' => 'Overføre filer',
    'Installed Plugins' => 'Installerede udvidelses-moduler',
    'Plugin Directory' => 'Udvidelses-modul katalog',
    'Plugin installed successfully.' => 'Udvidelses-modul installeret.',
    'Plugin updated successfully.' => 'Udvidelses-modul opdateret.',
    'Plugin removed successfully.' => 'Udvidelses-modul fjernet.',
    'Subtask converted to task successfully.' => 'Delopgave konverteret til opgave.',
    'Unable to convert the subtask.' => 'Kan ikke konvertere delopgave.',
    'Unable to extract plugin archive.' => 'Kan ikke udpakke udvidelses-modul arkiv.',
    'Plugin not found.' => 'Udvidelses-modul ikke fundet.',
    'You don\'t have the permission to remove this plugin.' => 'Ikke tilladelse til at fjerne udvidelses-modul.',
    'Unable to download plugin archive.' => 'Kan ikke hente udvidelses-modul arkiv.',
    'Unable to write temporary file for plugin.' => 'Kan ikke skrive midlertidig fil til udvidelses-modul.',
    'Unable to open plugin archive.' => 'Kan ikke åbne udvidelses-modul arkiv.',
    'There is no file in the plugin archive.' => 'Ingen fil i udvidelses-modul arkivet.',
    'Create tasks in bulk' => 'Opret flere opgaver',
    'Your Kanboard instance is not configured to install plugins from the user interface.' => 'Kanboard forekomst er ikke indstillettil at installere udvidelses-moduler fra brugergrænsefladen.',
    'There is no plugin available.' => 'Ingen udvidelses-modul til rådighed.',
    'Install' => 'Installere',
    'Update' => 'Opdatere',
    'Up to date' => 'Opdateret',
    'Not available' => 'Ikke tilgængelig',
    'Remove plugin' => 'Fjern udvidelses-modul',
    'Do you really want to remove this plugin: "%s"?' => 'Fjern udvidelses-modul: "%s"?',
    'Uninstall' => 'Afinstallere',
    'Listing' => 'Kategorisere',
    'Metadata' => 'Metadata',
    'Manage projects' => 'Projekt styring',
    'Convert to task' => 'Konvertere til opgave',
    'Convert sub-task to task' => 'Konvertere delopgave til opgave',
    'Do you really want to convert this sub-task to a task?' => 'Konvertere delopgave til opgave?',
    'My task title' => 'Tildelt opgave titel',
    'Enter one task by line.' => 'Indtast én opgave pr. linje.',
    'Number of failed login:' => 'Antal mislykkede log ind:',
    'Account locked until:' => 'Konto låst indtil:',
    'Email settings' => 'E-post indstillinger',
    'Email sender address' => 'E-post afsender adresse',
    'Email transport' => 'E-post transport',
    'Webhook token' => 'Net-hægte symbol',
    'Project tags management' => 'Projekt mærke styring',
    'Tag created successfully.' => 'Mærke oprettet.',
    'Unable to create this tag.' => 'Kunne ikke oprette mærke.',
    'Tag updated successfully.' => 'Mærke opdateret.',
    'Unable to update this tag.' => 'Kan ikke opdatere mærke.',
    'Tag removed successfully.' => 'Mærke fjernet.',
    'Unable to remove this tag.' => 'Kan ikke fjerne mærke.',
    'Global tags management' => 'Global mærke styring',
    'Tags' => 'Mærker',
    'Tags management' => 'Mærke styring',
    'Add new tag' => 'Tilføj nyt mærke',
    'Edit a tag' => 'Redigere mærke',
    'Project tags' => 'Projekt mærker',
    'There is no specific tag for this project at the moment.' => 'Ingen specifik projekt mærke i øjeblikket.',
    'Tag' => 'Mærke',
    'Remove a tag' => 'Fjern et mærke',
    'Do you really want to remove this tag: "%s"?' => 'Fjern mærke: "%s"?',
    'Global tags' => 'Globale mærker',
    'There is no global tag at the moment.' => 'Ingen global mærke i øjeblikket.',
    'This field cannot be empty' => 'Feltet kan ikke være tomt',
    'Close a task when there is no activity in a specific column' => 'Lukke opgave når der ikke er nogen aktivitet i bestemt kolonne',
    '%s removed a subtask for the task #%d' => '%s fjernet delopgave til opgave #%d',
    '%s removed a comment on the task #%d' => '%s fjernet kommentar til opgave #%d',
    'Comment removed on task #%d' => 'Kommentar fjernet til opgave #%d',
    'Subtask removed on task #%d' => 'Delopgave fjernet til opgave #%d',
    'Hide tasks in this column in the dashboard' => 'Skjul opgaver i kolonne i instrumentbrættet',
    '%s removed a comment on the task %s' => '%s fjernet kommentar til opgave %s',
    '%s removed a subtask for the task %s' => '%s fjernet delopgave til opgave %s',
    'Comment removed' => 'Kommentar fjernet',
    'Subtask removed' => 'Delopgave fjernet',
    '%s set a new internal link for the task #%d' => '%s angive ny intern henvisning til opgave #%d',
    '%s removed an internal link for the task #%d' => '%s fjernet intern henvisning til opgave #%d',
    'A new internal link for the task #%d has been defined' => 'Ny intern henvisning til opgave #%d er bestemt',
    'Internal link removed for the task #%d' => 'Intern henvisning fjernet til opgave #%d',
    '%s set a new internal link for the task %s' => '%s angive ny intern henvisning til opgave %s',
    '%s removed an internal link for the task %s' => '%s fjernet intern henvisning til opgave %s',
    'Automatically set the due date on task creation' => 'Angive forfaldsdato automatisk ved oprettelse af opgave',
    'Move the task to another column when closed' => 'Flyt opgave til anden kolonne når den er lukket',
    'Move the task to another column when not moved during a given period' => 'Flyt opgave til anden kolonne når den ikke er flyttet i given periode',
    'Dashboard for %s' => 'Instrumentbræt for %s',
    'Tasks overview for %s' => 'Opgave oversigt for %s',
    'Subtasks overview for %s' => 'Delopgave oversigt for %s',
    'Projects overview for %s' => 'Projektoversigt for %s',
    'Activity stream for %s' => 'Aktivitet strøm for %s',
    'Assign a color when the task is moved to a specific swimlane' => 'Tildele farve når opgave flyttes til bestemt spor',
    'Assign a priority when the task is moved to a specific swimlane' => 'Tildele prioritet når opgave flyttes til bestemt spor',
    'User unlocked successfully.' => 'Bruger frigjort.',
    'Unable to unlock the user.' => 'Kan ikke frigøre bruger.',
    'Move a task to another swimlane' => 'Flyt opgave til andet spor',
    'Creator Name' => 'Opretter navn',
    'Time spent and estimated' => 'Tid brugt og anslået',
    'Move position' => 'Flyt placering',
    'Move task to another position on the board' => 'Flyt opgave til anden placering på tavle',
    'Insert before this task' => 'Indsæt før opgave',
    'Insert after this task' => 'Indsæt efter opgave',
    'Unlock this user' => 'Frigøre bruger',
    'Custom Project Roles' => 'Brugertilpasset projektroller',
    'Add a new custom role' => 'Tilføj ny brugertilpasset rolle',
    'Restrictions for the role "%s"' => 'Begrænsninger for rolle "%s"',
    'Add a new project restriction' => 'Tilføj ny projektbegrænsning',
    'Add a new drag and drop restriction' => 'Tilføj ny træk og slip begrænsning',
    'Add a new column restriction' => 'Tilføj ny kolonne begrænsning',
    'Edit this role' => 'Redigere rolle',
    'Remove this role' => 'Fjern rolle',
    'There is no restriction for this role.' => 'Ingen begrænsninger for rolle.',
    'Only moving task between those columns is permitted' => 'Det er kun tilladt at flytte opgave mellem disse kolonner',
    'Close a task in a specific column when not moved during a given period' => 'Lukke opgave i bestemt kolonne når den ikke er flyttet i given periode',
    'Edit columns' => 'Redigere kolonner',
    'The column restriction has been created successfully.' => 'Kolonne begrænsning oprettet.',
    'Unable to create this column restriction.' => 'Kan ikke oprette kolonne begrænsning.',
    'Column restriction removed successfully.' => 'Kolonne begrænsning fjernet.',
    'Unable to remove this restriction.' => 'Kan ikke fjerne begrænsning.',
    'Your custom project role has been created successfully.' => 'Brugertilpasset projektrolle oprettet.',
    'Unable to create custom project role.' => 'Kan ikke oprette brugertilpasset projekt rolle.',
    'Your custom project role has been updated successfully.' => 'Brugertilpasset projektrolle opdateret.',
    'Unable to update custom project role.' => 'Kan ikke opdatere brugertilpasset projekt rolle.',
    'Custom project role removed successfully.' => 'Brugertilpasset projektrolle fjernet.',
    'Unable to remove this project role.' => 'Kan ikke fjerne projekt rolle.',
    'The project restriction has been created successfully.' => 'Projektbegrænsningen oprettet.',
    'Unable to create this project restriction.' => 'Kan ikke oprette projekt begrænsning.',
    'Project restriction removed successfully.' => 'Projektbegrænsningen fjernet.',
    'You cannot create tasks in this column.' => 'Kan ikke oprette opgaver i kolonne.',
    'Task creation is permitted for this column' => 'Opgaveoprettelse tilladt for kolonne',
    'Closing or opening a task is permitted for this column' => 'Lukning eller åbning af opgave tilladt for kolonne',
    'Task creation is blocked for this column' => 'Opgaveoprettelse blokeret for kolonne',
    'Closing or opening a task is blocked for this column' => 'Lukning eller åbning af opgave blokeret for kolonne',
    'Task creation is not permitted' => 'Opgaveoprettelse ikke tilladt',
    'Closing or opening a task is not permitted' => 'Lukning eller åbning af opgave ikke tilladt',
    'New drag and drop restriction for the role "%s"' => 'Ny træk og slip begrænsning for rolle "%s"',
    'People belonging to this role will be able to move tasks only between the source and the destination column.' => 'Personer med denne rolle kan flytte opgaver mellem kilde og destinations kolonne.',
    'Remove a column restriction' => 'Fjern kolonne begrænsning',
    'Do you really want to remove this column restriction: "%s" to "%s"?' => 'Fjern kolonne begrænsning: "%s" til "%s"?',
    'New column restriction for the role "%s"' => 'Ny kolonne begrænsning for rolle "%s"',
    'Rule' => 'Regel',
    'Do you really want to remove this column restriction?' => 'Fjern kolonne begrænsning?',
    'Custom roles' => 'Brugertilpassede roller',
    'New custom project role' => 'Ny brugertilpasset projektrolle',
    'Edit custom project role' => 'Redigere brugertilpasset projektrolle',
    'Remove a custom role' => 'Fjern brugertilpasset rolle',
    'Do you really want to remove this custom role: "%s"? All people assigned to this role will become project member.' => 'Fjern brugertilpasset rolle: "%s"? Alle personer tildelt rolle bliver projektmedlem.',
    'There is no custom role for this project.' => 'Ingen brugertilpasset rolle for projekt.',
    'New project restriction for the role "%s"' => 'Ny projektbegrænsning for rolle "%s"',
    'Restriction' => 'Begrænsning',
    'Remove a project restriction' => 'Fjern projektbegrænsning',
    'Do you really want to remove this project restriction: "%s"?' => 'Fjern projektbegrænsning: "%s"?',
    'Duplicate to multiple projects' => 'Kopiere til flere projekter',
    'This field is required' => 'Felt er påkrævet',
    'Moving a task is not permitted' => 'Ikke tilladt at flytte opgave',
    'This value must be in the range %d to %d' => 'Værdi skal ligge i område %d til %d',
    'You are not allowed to move this task.' => 'Ikke tilladelse til at flytte opgave.',
    'API User Access' => 'API bruger adgang',
    'Preview' => 'Forhånds-visning',
    'Write' => 'Skriv',
    'Write your text in Markdown' => 'Skriv tekst i mark-down format',
    'No personal API access token registered.' => 'Ingen personlig API adgangsymbol registreret.',
    'Your personal API access token is "%s"' => 'Personlig API adgangsymbol er "%s"',
    'Remove your token' => 'Fjern symbol',
    'Generate a new token' => 'Generere nyt symbol',
    'Showing %d-%d of %d' => 'Viser %d-%d af %d',
    'Outgoing Emails' => 'Udgående e-post',
    'Add or change currency rate' => 'Tilføj eller ændre valutakurs',
    'Reference currency: %s' => 'Referencevaluta: %s',
    'Add custom filters' => 'Tilføj brugertilpasset filtre',
    'Export' => 'Eksport',
    'Add link label' => 'Tilføj henvisnings etiket',
    'Incompatible Plugins' => 'Inkompatibel udvidelses-moduler',
    'Compatibility' => 'Kompatibilitet',
    'Permissions and ownership' => 'Tilladelser og ejerskab',
    'Priorities' => 'Prioriteter',
    'Close this window' => 'Lukke vindue',
    'Unable to upload this file.' => 'Kan ikke overføre fil.',
    'Import tasks' => 'Importere opgaver',
    'Choose a project' => 'Vælge projekt',
    'Profile' => 'Profil',
    'Application role' => 'Program rolle',
    '%d invitations were sent.' => '%d invitationer blev sendt.',
    '%d invitation was sent.' => '%d invitation blev sendt.',
    'Unable to create this user.' => 'Kan ikke oprette bruger.',
    'Kanboard Invitation' => 'Kanboard invitation',
    'Visible on dashboard' => 'Synlig på instrumentbræt',
    'Created at:' => 'Oprettet på:',
    'Updated at:' => 'Opdateret på:',
    'There is no custom filter.' => 'Ingen brugertilpasset filter.',
    'New User' => 'Ny Bruger',
    'Authentication' => 'Godkendelse',
    'If checked, this user will use a third-party system for authentication.' => 'Hvis markeret vil bruger bruge et tredjeparts system til godkendelse.',
    'The password is necessary only for local users.' => 'Adgangskode er kun nødvendig for lokale brugere.',
    'You have been invited to register on Kanboard.' => 'Invitation til at registrere på Kanboard.',
    'Click here to join your team' => 'Klik her for at deltage på holdet',
    'Invite people' => 'Invitere personer',
    'Emails' => 'E-post',
    'Enter one email address by line.' => 'Indtaste e-post adresse pr. linje.',
    'Add these people to this project' => 'Tilføj disse personer til projekt',
    'Add this person to this project' => 'Tilføj person til projekt',
    'Sign-up' => 'Tilmelde',
    'Credentials' => 'Legitimations-oplysninger',
    'New user' => 'Ny bruger',
    'This username is already taken' => 'Brugernavn optaget',
    'Your profile must have a valid email address.' => 'Profil skal have gyldig e-post adresse.',
    'TRL - Turkish Lira' => 'TRL - tyrkisk lire',
    'The project email is optional and could be used by several plugins.' => 'Projekt e-post adresse valgfri og kan bruges af flere udvidelses-moduler.',
    'The project email must be unique across all projects' => 'Projekt e-post adresse skal være unik på tværs af projekter',
    'The email configuration has been disabled by the administrator.' => 'E-post indstilling deaktiveret af administrator.',
    'Close this project' => 'Lukke projekt',
    'Open this project' => 'Åbne projekt',
    'Close a project' => 'Lukke projekt',
    'Do you really want to close this project: "%s"?' => 'Lukke projekt: "%s"?',
    'Reopen a project' => 'Genåbne projekt',
    'Do you really want to reopen this project: "%s"?' => 'Genåbne projekt: "%s"?',
    'This project is open' => 'Projekt åben',
    'This project is closed' => 'Projekt lukket',
    'Unable to upload files, check the permissions of your data folder.' => 'Kan ikke overføre filer, kontrollere mappe tilladelser.',
    'Another category with the same name exists in this project' => 'Anden kategori med samme navn i projekt',
    'Comment sent by email successfully.' => 'Kommentar sendt via e-post.',
    'Sent by email to "%s" (%s)' => 'Sendt via e-post til "%s" (%s)',
    'Unable to read uploaded file.' => 'Kan ikke læse overført fil.',
    'Database uploaded successfully.' => 'Database overført.',
    'Task sent by email successfully.' => 'Opgave sendt via e-post.',
    'There is no category in this project.' => 'Ingen kategori i projekt.',
    'Send by email' => 'Send via e-post',
    'Create and send a comment by email' => 'Opret og send kommentar via e-post',
    'Subject' => 'Emne',
    'Upload the database' => 'Overføre database',
    'You could upload the previously downloaded Sqlite database (Gzip format).' => 'Overføre tidligere hentede SQL-database (Gzip format).',
    'Database file' => 'Databasefil',
    'Upload' => 'Overføre',
    'Your project must have at least one active swimlane.' => 'Projekt skal have mindst et aktivt spor.',
    'Project: %s' => 'Projekt: %s',
    'Automatic action not found: "%s"' => 'Automatisk handling ikke fundet: "%s"',
    '%d projects' => '%d projekter',
    '%d project' => '%d projekt',
    'There is no project.' => 'Ikke noget projekt.',
    'Sort' => 'Sortere',
    'Project ID' => 'Projekt ID',
    'Project name' => 'Projekt navn',
    'Public' => 'Offentlig',
    'Personal' => 'Privat',
    '%d tasks' => '%d opgaver',
    '%d task' => '%d opgave',
    'Task ID' => 'Opgave ID',
    'Assign automatically a color when due date is expired' => 'Tildele automatisk farve når forfaldsdato er udløbet',
    'Total score in this column across all swimlanes' => 'Samlet bedømmelse i kolonne på tværs af alle spor',
    'HRK - Kuna' => 'HRK - kroatisk kuna',
    'ARS - Argentine Peso' => 'ARS - argentinsk peso',
    'COP - Colombian Peso' => 'COP - colombiansk peso',
    '%d groups' => '%d grupper',
    '%d group' => '%d gruppe',
    'Group ID' => 'Gruppe ID',
    'External ID' => 'Ekstern ID',
    '%d users' => '%d brugere',
    '%d user' => '%d bruger',
    'Hide subtasks' => 'Skjul delopgaver',
    'Show subtasks' => 'Vis delopgaver',
    'Authentication Parameters' => 'Godkendelses-parametre',
    'API Access' => 'API adgang',
    'No users found.' => 'Ingen brugere fundet.',
    'User ID' => 'Bruger ID',
    'Notifications are activated' => 'Påmindelser aktiveret',
    'Notifications are disabled' => 'Påmindelser deaktiveret',
    'User disabled' => 'Bruger deaktiveret',
    '%d notifications' => '%d påmindelser',
    '%d notification' => '%d påmindelse',
    'There is no external integration installed.' => 'Ingen ekstern integration installeret.',
    'You are not allowed to update tasks assigned to someone else.' => 'Kan ikke opdatere opgaver tildelt anden bruger.',
    'You are not allowed to change the assignee.' => 'Kan ikke ændre ejer.',
    'Task suppression is not permitted' => 'Opgave undertrykkelse er ikke tilladt',
    'Changing assignee is not permitted' => 'Ændring af ansvarlig er ikke tilladt',
    'Update only assigned tasks is permitted' => 'Opdatere kun tilladt tildelte opgaver',
    'Only for tasks assigned to the current user' => 'Kun opgaver tildelt nuværende bruger',
    'My projects' => 'Tildelte projekter',
    'You are not a member of any project.' => 'Ikke medlem af noget projekt.',
    'My subtasks' => 'Tildelte delopgaver',
    '%d subtasks' => '%d delopgaver',
    '%d subtask' => '%d delopgave',
    'Only moving task between those columns is permitted for tasks assigned to the current user' => 'Kun opgave flyt mellem disse kolonner er tilladt for opgaver tildelt nuværende bruger',
    '[DUPLICATE]' => '[KOPIERE]',
    'DKK - Danish Krona' => 'DKK - dansk krone',
    'Remove user from group' => 'Fjern bruger fra gruppe',
    'Assign the task to its creator' => 'Tildele opgave til opretter',
    'This task was sent by email to "%s" with subject "%s".' => 'Opgave sendt via e-post til "%s" med emne "%s".',
    'Predefined Email Subjects' => 'Forudbestemte e-post emner',
    'Write one subject by line.' => 'Skriv ét emne pr. linje.',
    'Create another link' => 'Opret anden henvisning',
    'BRL - Brazilian Real' => 'BRL - brasiliansk real',
    'Add a new Kanboard task' => 'Tilføj ny Kanboard opgave',
    'Subtask not started' => 'Delopgave ikke startet',
    'Subtask currently in progress' => 'Delopgave i gang',
    'Subtask completed' => 'Delopgave afsluttet',
    'Subtask added successfully.' => 'Delopgave tilføjet.',
    '%d subtasks added successfully.' => '%d delopgaver tilføjet.',
    'Enter one subtask by line.' => 'Indtaste én delopgave pr. linje.',
    'Predefined Contents' => 'Forudbestemt indhold',
    'Predefined contents' => 'Forudbestemt indhold',
    'Predefined Task Description' => 'Forudbestemt opgavebeskrivelse',
    'Do you really want to remove this template? "%s"' => 'Fjern skabelon? "%s"',
    'Add predefined task description' => 'Tilføj forudbestemt opgavebeskrivelse',
    'Predefined Task Descriptions' => 'Forudbestemte opgavebeskrivelser',
    'Template created successfully.' => 'Skabelonen oprettet.',
    'Unable to create this template.' => 'Kan ikke oprette skabelon.',
    'Template updated successfully.' => 'Skabelon opdateret.',
    'Unable to update this template.' => 'Kan ikke opdatere skabelon.',
    'Template removed successfully.' => 'Skabelon fjernet.',
    'Unable to remove this template.' => 'Kan ikke fjerne skabelon.',
    'Template for the task description' => 'Skabelon til opgavebeskrivelse',
    'The start date is greater than the end date' => 'Startdato er større end slutdato',
    'Tags must be separated by a comma' => 'Mærker skal adskilles med komma',
    'Only the task title is required' => 'Kun opgave titel påkrævet',
    'Creator Username' => 'Opretters brugernavn',
    'Color Name' => 'Farve navn',
    'Column Name' => 'Kolonne navn',
    'Swimlane Name' => 'Spor navn',
    'Time Estimated' => 'Tid anslået',
    'Time Spent' => 'Tid brugt',
    'External Link' => 'Ekstern henvisning',
    'This feature enables the iCal feed, RSS feed and the public board view.' => 'Funktionen aktiverer iCal og RSS nyheds-kilde samt offentlig tavle visning.',
    'Stop the timer of all subtasks when moving a task to another column' => 'Stop tidsuret for alle delopgaver når opgave flyttes til anden kolonne',
    'Subtask Title' => 'Delopgave titel',
    'Add a subtask and activate the timer when moving a task to another column' => 'Tilføj delopgave og aktivere tidsuret når opgave flyttes til anden kolonne',
    'days' => 'dage',
    'minutes' => 'minutter',
    'seconds' => 'sekunder',
    'Assign automatically a color when preset start date is reached' => 'Tildel automatisk farve når forudindstillet startdato er nået',
    'Move the task to another column once a predefined start date is reached' => 'Flyt opgave til anden kolonne når forudbestemt startdato er nået',
    'This task is now linked to the task %s with the relation "%s"' => 'Opgave henviser til opgave %s med relation "%s"',
    'The link with the relation "%s" to the task %s has been removed' => 'Henvisning med relation "%s" til opgave %s er fjernet',
    'Custom Filter:' => 'Brugertilpasset filter:',
    'Unable to find this group.' => 'Kan ikke finde gruppe.',
    '%s moved the task #%d to the column "%s"' => '%s flyttet opgave #%d til kolonne "%s"',
    '%s moved the task #%d to the position %d in the column "%s"' => '%s flyttet opgave #%d til placering %d i kolonne "%s"',
    '%s moved the task #%d to the swimlane "%s"' => '%s flyttet opgave #%d til spor "%s"',
    '%sh spent' => '%sh brugt',
    '%sh estimated' => '%sh anslået',
    'Select All' => 'Vælge alle',
    'Unselect All' => 'Fravælge alle',
    'Apply action' => 'Anvende handling',
    'Move selected tasks to another column or swimlane' => 'Flyt valgte opgaver til anden kolonne',
    'Edit tasks in bulk' => 'Masse redigere opgaver',
    'Choose the properties that you would like to change for the selected tasks.' => 'Vælg egenskaber som skal ændres for de valgte opgaver.',
    'Configure this project' => 'Indstille projekt',
    'Start now' => 'Start nu',
    '%s removed a file from the task #%d' => '%s fjernede en fil fra opgave #%d',
    'Attachment removed from task #%d: %s' => 'Vedhæftet fjernet fra opgave #%d: %s',
    'No color' => 'Ingen farve',
    'Attachment removed "%s"' => 'Vedhæftet fjernet "%s"',
    '%s removed a file from the task %s' => '%s fjernede en fil fra opgave %s',
    'Move the task to another swimlane when assigned to a user' => 'Flyt opgave til andet spor når tildelt anden bruger',
    'Destination swimlane' => 'Mål spor',
    'Assign a category when the task is moved to a specific swimlane' => 'Tildele kategori når opgave flyttes til anført spor',
    'Move the task to another swimlane when the category is changed' => 'Flyt opgave til andet spor når kategori ændres',
    'Reorder this column by priority (ASC)' => 'Sortere kolonne efter prioritet (ASC)',
    'Reorder this column by priority (DESC)' => 'Sortere kolonne efter prioritet (DESC)',
    'Reorder this column by assignee and priority (ASC)' => 'Sortere kolonne efter ansvarlig og prioritet (ASC)',
    'Reorder this column by assignee and priority (DESC)' => 'Sortere kolonne efter ansvarlig og prioritet (DESC)',
    'Reorder this column by assignee (A-Z)' => 'Sorter kolonne efter ansvarlig (A-Z)',
    'Reorder this column by assignee (Z-A)' => 'Sorter kolonne efter ansvarlig (Z-A)',
    'Reorder this column by due date (ASC)' => 'Sorter kolonne efter udløbstid (ASC)',
    'Reorder this column by due date (DESC)' => 'Sorter kolonne efter udløbstid (DESC)',
    'Reorder this column by id (ASC)' => 'Sortér denne kolonne efter id (stigende)',
    'Reorder this column by id (DESC)' => 'Sortér denne kolonne efter id (faldende)',
    '%s moved the task #%d "%s" to the project "%s"' => '%s flyttet opgave #%d "%s" til projekt "%s"',
    'Task #%d "%s" has been moved to the project "%s"' => 'Opgave #%d "%s" er flyttet til projekt "%s"',
    'Move the task to another column when the due date is less than a certain number of days' => 'Flyt opgave til anden kolonne når afleveringsdato er mindre end et bestemt antal dage',
    'Automatically update the start date when the task is moved away from a specific column' => 'Opdatere automatisk startdato når opgaven flyttes væk fra bestemt kolonne',
    'HTTP Client:' => 'HTTP klient:',
    'Assigned' => 'Tildelt',
    'Task limits apply to each swimlane individually' => 'Opgavegrænser gælder individuelt for hvert sport',
    'Column task limits apply to each swimlane individually' => 'Kolonne opgave grænser gælder individuelt for hvert spor',
    'Column task limits are applied to each swimlane individually' => 'Kolonne opgave grænser anvendes individuelt på hvert spor',
    'Column task limits are applied across swimlanes' => 'Kolonne opgave grænser anvendes på tværs af spor',
    'Task limit: ' => 'Opgave grænser:',
    'Change to global tag' => 'Ændre til globalt mærke',
    'Do you really want to make the tag "%s" global?' => 'Skal mærket "%s" gøres globalt?',
    'Enable global tags for this project' => 'Aktivere globale mærker for dette projekt',
    'Group membership(s):' => 'Gruppe medlemskab',
    '%s is a member of the following group(s): %s' => '%s er medlem af følgende gruppe(r): %s',
    '%d/%d group(s) shown' => '%d/%d gruppe(r) vist',
    'Subtask creation or modification' => 'Underopgave oprettelse eller ændring',
    'Assign the task to a specific user when the task is moved to a specific swimlane' => 'Tildele opgave til bestemt bruger når opgave flyttes til anført spor',
    'Comment' => 'Kommentar',
    'Collapse vertically' => 'Sammenfolde lodret',
    'Expand vertically' => 'Udvide lodret',
    'MXN - Mexican Peso' => 'Mexicansk Peso',
    'Estimated vs actual time per column' => 'Anslået mod faktisk tid pr. kolonne',
    'HUF - Hungarian Forint' => 'HUF - Ungarsk forint',
    'XBT - Bitcoin' => 'XBT - Bitcoin',
    'You must select a file to upload as your avatar!' => 'Vælg fil som overføres som profil billede!',
    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'Overført fil er ikke et gyldigt billede! (*.gif, *.jpg, *.jpeg eller *.png)',
    'Automatically set the due date when the task is moved away from a specific column' => 'Sæt automatisk afleveringsdato når opgave er flyttet væk fra en bestemt kolonne',
    'No other projects found.' => 'Ingen andre projekter fundet.',
    'Tasks copied successfully.' => 'Opgaver blev kopieret med succes.',
    'Unable to copy tasks.' => 'Kunne ikke kopiere opgaver.',
    'Theme' => 'Tema',
    'Theme:' => 'Tema:',
    'Light theme' => 'Lyst tema',
    'Dark theme' => 'Mørkt tema',
    'Automatic theme - Sync with system' => 'Automatisk tema – synkroniser med systemet',
    'Application managers or more' => 'Applikationsansvarlige eller højere',
    'Administrators' => 'Administratorer',
    'Visibility:' => 'Synlighed:',
    'Standard users' => 'Standardbrugere',
    'Visibility is required' => 'Synlighed er påkrævet',
    'The visibility should be an app role' => 'Synligheden skal være en app-rolle',
    'Reply' => 'Svar',
    '%s wrote: ' => '%s skrev: ',
    'Number of visible tasks in this column and swimlane' => 'Antal synlige opgaver i denne kolonne og bane',
    'Number of tasks in this swimlane' => 'Antal opgaver i denne bane',
    'Unable to find another subtask in progress, you can close this window.' => 'Kunne ikke finde en anden underopgave i gang, du kan lukke dette vindue.',
    'This theme is invalid' => 'Dette tema er ugyldigt',
    'This role is invalid' => 'Denne rolle er ugyldig',
    'This timezone is invalid' => 'Denne tidszone er ugyldig',
    'This language is invalid' => 'Dette sprog er ugyldigt',
    'This URL is invalid' => 'Denne URL er ugyldig',
    'Date format invalid' => 'Ugyldigt datoformat',
    'Time format invalid' => 'Ugyldigt tidsformat',
    'Invalid Mail transport' => 'Ugyldig mailtransport',
    'Color invalid' => 'Ugyldig farve',
    'This value must be greater or equal to %d' => 'Værdien skal være større end eller lig med %d',
    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => 'Tilføj en BOM i begyndelsen af filen (krævet af Microsoft Excel)',
    'Just add these tag(s)' => 'Tilføj blot disse mærker',
    'Remove internal link(s)' => 'Fjern interne links',
    'Import tasks from another project' => 'Importer opgaver fra et andet projekt',
    'Select the project to copy tasks from' => 'Vælg projektet, du vil kopiere opgaver fra',
    'The total maximum allowed attachments size is %sB.' => 'Den samlede maksimalt tilladte størrelse for vedhæftede filer er %sB.',
    'Add attachments' => 'Tilføj vedhæftede filer',
    'Task #%d "%s" is overdue' => 'Opgave #%d "%s" er forfalden',
    'Enable notifications by default for all new users' => 'Aktiver påmindelser som standard for alle nye brugere',
];
